==> org-lsst-sal-atcamera-2.5.0-sources.jar: org/lsst/sal/atcamera/event/Focal_plane_Reb_timersConfigurationEvent.java <==
package org.lsst.sal.atcamera.event;

import java.util.Arrays;
import org.lsst.sal.camera.CameraEvent;

public class Focal_plane_Reb_timersConfigurationEvent extends CameraEvent {
  private final String version;

  private final String location;

  private final long[] periodictasks_monitor_check_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_boardPower_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_crVolt_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_rebTemp_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_aspicTemp_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_boardPower_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_crVolt_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_rebTemp_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_taskPeriodMillis;

  public Focal_plane_Reb_timersConfigurationEvent(int priority, String version, String location,
      long[] periodictasks_monitor_check_taskPeriodMillis,
      long[] periodictasks_monitor_publish_aspicTemp_taskPeriodMillis,
      long[] periodictasks_monitor_publish_boardPower_taskPeriodMillis,
      long[] periodictasks_monitor_publish_crVolt_taskPeriodMillis,
      long[] periodictasks_monitor_publish_rebTemp_taskPeriodMillis,
      long[] periodictasks_monitor_publish_taskPeriodMillis,
      long[] periodictasks_monitor_update_aspicTemp_taskPeriodMillis,
      long[] periodictasks_monitor_update_boardPower_taskPeriodMillis,
      long[] periodictasks_monitor_update_crVolt_taskPeriodMillis,
      long[] periodictasks_monitor_update_rebTemp_taskPeriodMillis,
      long[] periodictasks_monitor_update_taskPeriodMillis) {
    super (priority);
    this.version = version;
    this.location = location;
    this.periodictasks_monitor_check_taskPeriodMillis = periodictasks_monitor_check_taskPeriodMillis;
    this.periodictasks_monitor_publish_aspicTemp_taskPeriodMillis = periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;
    this.periodictasks_monitor_publish_boardPower_taskPeriodMillis = periodictasks_monitor_publish_boardPower_taskPeriodMillis;
    this.periodictasks_monitor_publish_crVolt_taskPeriodMillis = periodictasks_monitor_publish_crVolt_taskPeriodMillis;
    this.periodictasks_monitor_publish_rebTemp_taskPeriodMillis = periodictasks_monitor_publish_rebTemp_taskPeriodMillis;
    this.periodictasks_monitor_publish_taskPeriodMillis = periodictasks_monitor_publish_taskPeriodMillis;
    this.periodictasks_monitor_update_aspicTemp_taskPeriodMillis = periodictasks_monitor_update_aspicTemp_taskPeriodMillis;
    this.periodictasks_monitor_update_boardPower_taskPeriodMillis = periodictasks_monitor_update_boardPower_taskPeriodMillis;
    this.periodictasks_monitor_update_crVolt_taskPeriodMillis = periodictasks_monitor_update_crVolt_taskPeriodMillis;
    this.periodictasks_monitor_update_rebTemp_taskPeriodMillis = periodictasks_monitor_update_rebTemp_taskPeriodMillis;
    this.periodictasks_monitor_update_taskPeriodMillis = periodictasks_monitor_update_taskPeriodMillis;
  }

  public String getVersion() {
    return version;
  }

  public String getLocation() {
    return location;
  }

  public long[] getPeriodictasks_monitor_check_taskPeriodMillis() {
    return periodictasks_monitor_check_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_aspicTemp_taskPeriodMillis() {
    return periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_boardPower_taskPeriodMillis() {
    return periodictasks_monitor_publish_boardPower_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_crVolt_taskPeriodMillis() {
    return periodictasks_monitor_publish_crVolt_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_rebTemp_taskPeriodMillis() {
    return periodictasks_monitor_publish_rebTemp_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_taskPeriodMillis() {
    return periodictasks_monitor_publish_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_aspicTemp_taskPeriodMillis() {
    return periodictasks_monitor_update_aspicTemp_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_boardPower_taskPeriodMillis() {
    return periodictasks_monitor_update_boardPower_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_crVolt_taskPeriodMillis() {
    return periodictasks_monitor_update_crVolt_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_rebTemp_taskPeriodMillis() {
    return periodictasks_monitor_update_rebTemp_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_taskPeriodMillis() {
    return periodictasks_monitor_update_taskPeriodMillis;
  }

  @Override
  public String toString() {
    return "Focal_plane_Reb_timersConfigurationEvent{" + "version=" + version +
        ", location=" + location +
        ", periodictasks_monitor_check_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_check_taskPeriodMillis) +
        ", periodictasks_monitor_publish_aspicTemp_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_aspicTemp_taskPeriodMillis) +
        ", periodictasks_monitor_publish_boardPower_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_boardPower_taskPeriodMillis) +
        ", periodictasks_monitor_publish_crVolt_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_crVolt_taskPeriodMillis) +
        ", periodictasks_monitor_publish_rebTemp_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_rebTemp_taskPeriodMillis) +
        ", periodictasks_monitor_publish_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_taskPeriodMillis) +
        ", periodictasks_monitor_update_aspicTemp_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_aspicTemp_taskPeriodMillis) +
        ", periodictasks_monitor_update_boardPower_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_boardPower_taskPeriodMillis) +
        ", periodictasks_monitor_update_crVolt_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_crVolt_taskPeriodMillis) +
        ", periodictasks_monitor_update_rebTemp_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_rebTemp_taskPeriodMillis) +
        ", periodictasks_monitor_update_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_taskPeriodMillis) +
        "}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private String location;

    private long[] periodictasks_monitor_check_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_boardPower_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_crVolt_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_rebTemp_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_taskPeriodMillis;

    private long[] periodictasks_monitor_update_aspicTemp_taskPeriodMillis;

    private long[] periodictasks_monitor_update_boardPower_taskPeriodMillis;

    private long[] periodictasks_monitor_update_crVolt_taskPeriodMillis;

    private long[] periodictasks_monitor_update_rebTemp_taskPeriodMillis;

    private long[] periodictasks_monitor_update_taskPeriodMillis;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder location(String location) {
      this.location = location;
      return this;
    }

    public Builder periodictasks_monitor_check_taskPeriodMillis(
        long[] periodictasks_monitor_check_taskPeriodMillis) {
      this.periodictasks_monitor_check_taskPeriodMillis = periodictasks_monitor_check_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_aspicTemp_taskPeriodMillis(
        long[] periodictasks_monitor_publish_aspicTemp_taskPeriodMillis) {
      this.periodictasks_monitor_publish_aspicTemp_taskPeriodMillis = periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_boardPower_taskPeriodMillis(
        long[] periodictasks_monitor_publish_boardPower_taskPeriodMillis) {
      this.periodictasks_monitor_publish_boardPower_taskPeriodMillis = periodictasks_monitor_publish_boardPower_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_crVolt_taskPeriodMillis(
        long[] periodictasks_monitor_publish_crVolt_taskPeriodMillis) {
      this.periodictasks_monitor_publish_crVolt_taskPeriodMillis = periodictasks_monitor_publish_crVolt_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_rebTemp_taskPeriodMillis(
        long[] periodictasks_monitor_publish_rebTemp_taskPeriodMillis) {
      this.periodictasks_monitor_publish_rebTemp_taskPeriodMillis = periodictasks_monitor_publish_rebTemp_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_taskPeriodMillis(
        long[] periodictasks_monitor_publish_taskPeriodMillis) {
      this.periodictasks_monitor_publish_taskPeriodMillis = periodictasks_monitor_publish_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_aspicTemp_taskPeriodMillis(
        long[] periodictasks_monitor_update_aspicTemp_taskPeriodMillis) {
      this.periodictasks_monitor_update_aspicTemp_taskPeriodMillis = periodictasks_monitor_update_aspicTemp_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_boardPower_taskPeriodMillis(
        long[] periodictasks_monitor_update_boardPower_taskPeriodMillis) {
      this.periodictasks_monitor_update_boardPower_taskPeriodMillis = periodictasks_monitor_update_boardPower_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_crVolt_taskPeriodMillis(
        long[] periodictasks_monitor_update_crVolt_taskPeriodMillis) {
      this.periodictasks_monitor_update_crVolt_taskPeriodMillis = periodictasks_monitor_update_crVolt_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_rebTemp_taskPeriodMillis(
        long[] periodictasks_monitor_update_rebTemp_taskPeriodMillis) {
      this.periodictasks_monitor_update_rebTemp_taskPeriodMillis = periodictasks_monitor_update_rebTemp_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_taskPeriodMillis(
        long[] periodictasks_monitor_update_taskPeriodMillis) {
      this.periodictasks_monitor_update_taskPeriodMillis = periodictasks_monitor_update_taskPeriodMillis;
      return this;
    }

    public Focal_plane_Reb_timersConfigurationEvent build() {
      return new Focal_plane_Reb_timersConfigurationEvent(priority, version, location, periodictasks_monitor_check_taskPeriodMillis, periodictasks_monitor_publish_aspicTemp_taskPeriodMillis, periodictasks_monitor_publish_boardPower_taskPeriodMillis, periodictasks_monitor_publish_crVolt_taskPeriodMillis, periodictasks_monitor_publish_rebTemp_taskPeriodMillis, periodictasks_monitor_publish_taskPeriodMillis, periodictasks_monitor_update_aspicTemp_taskPeriodMillis, periodictasks_monitor_update_boardPower_taskPeriodMillis, periodictasks_monitor_update_crVolt_taskPeriodMillis, periodictasks_monitor_update_rebTemp_taskPeriodMillis, periodictasks_monitor_update_taskPeriodMillis);
    }
  }
}

==> org-lsst-sal-atcamera-2.5.4-sources.jar: org/lsst/sal/atcamera/event/Focal_plane_Reb_timersConfigurationEvent.java <==
package org.lsst.sal.atcamera.event;

import java.util.Arrays;
import org.lsst.sal.camera.CameraEvent;

public class Focal_plane_Reb_timersConfigurationEvent extends CameraEvent {
  private final String version;

  private final String location;

  private final long[] periodictasks_monitor_check_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_boardPower_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_crVolt_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_rebTemp_taskPeriodMillis;

  private final long[] periodictasks_monitor_publish_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_aspicTemp_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_boardPower_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_crVolt_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_rebTemp_taskPeriodMillis;

  private final long[] periodictasks_monitor_update_taskPeriodMillis;

  public Focal_plane_Reb_timersConfigurationEvent(String version, String location,
      long[] periodictasks_monitor_check_taskPeriodMillis,
      long[] periodictasks_monitor_publish_aspicTemp_taskPeriodMillis,
      long[] periodictasks_monitor_publish_boardPower_taskPeriodMillis,
      long[] periodictasks_monitor_publish_crVolt_taskPeriodMillis,
      long[] periodictasks_monitor_publish_rebTemp_taskPeriodMillis,
      long[] periodictasks_monitor_publish_taskPeriodMillis,
      long[] periodictasks_monitor_update_aspicTemp_taskPeriodMillis,
      long[] periodictasks_monitor_update_boardPower_taskPeriodMillis,
      long[] periodictasks_monitor_update_crVolt_taskPeriodMillis,
      long[] periodictasks_monitor_update_rebTemp_taskPeriodMillis,
      long[] periodictasks_monitor_update_taskPeriodMillis) {
    this.version = version;
    this.location = location;
    this.periodictasks_monitor_check_taskPeriodMillis = periodictasks_monitor_check_taskPeriodMillis;
    this.periodictasks_monitor_publish_aspicTemp_taskPeriodMillis = periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;
    this.periodictasks_monitor_publish_boardPower_taskPeriodMillis = periodictasks_monitor_publish_boardPower_taskPeriodMillis;
    this.periodictasks_monitor_publish_crVolt_taskPeriodMillis = periodictasks_monitor_publish_crVolt_taskPeriodMillis;
    this.periodictasks_monitor_publish_rebTemp_taskPeriodMillis = periodictasks_monitor_publish_rebTemp_taskPeriodMillis;
    this.periodictasks_monitor_publish_taskPeriodMillis = periodictasks_monitor_publish_taskPeriodMillis;
    this.periodictasks_monitor_update_aspicTemp_taskPeriodMillis = periodictasks_monitor_update_aspicTemp_taskPeriodMillis;
    this.periodictasks_monitor_update_boardPower_taskPeriodMillis = periodictasks_monitor_update_boardPower_taskPeriodMillis;
    this.periodictasks_monitor_update_crVolt_taskPeriodMillis = periodictasks_monitor_update_crVolt_taskPeriodMillis;
    this.periodictasks_monitor_update_rebTemp_taskPeriodMillis = periodictasks_monitor_update_rebTemp_taskPeriodMillis;
    this.periodictasks_monitor_update_taskPeriodMillis = periodictasks_monitor_update_taskPeriodMillis;
  }

  public String getVersion() {
    return version;
  }

  public String getLocation() {
    return location;
  }

  public long[] getPeriodictasks_monitor_check_taskPeriodMillis() {
    return periodictasks_monitor_check_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_aspicTemp_taskPeriodMillis() {
    return periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_boardPower_taskPeriodMillis() {
    return periodictasks_monitor_publish_boardPower_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_crVolt_taskPeriodMillis() {
    return periodictasks_monitor_publish_crVolt_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_rebTemp_taskPeriodMillis() {
    return periodictasks_monitor_publish_rebTemp_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_publish_taskPeriodMillis() {
    return periodictasks_monitor_publish_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_aspicTemp_taskPeriodMillis() {
    return periodictasks_monitor_update_aspicTemp_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_boardPower_taskPeriodMillis() {
    return periodictasks_monitor_update_boardPower_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_crVolt_taskPeriodMillis() {
    return periodictasks_monitor_update_crVolt_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_rebTemp_taskPeriodMillis() {
    return periodictasks_monitor_update_rebTemp_taskPeriodMillis;
  }

  public long[] getPeriodictasks_monitor_update_taskPeriodMillis() {
    return periodictasks_monitor_update_taskPeriodMillis;
  }

  @Override
  public String toString() {
    return "Focal_plane_Reb_timersConfigurationEvent{" + "version=" + version +
        ", location=" + location +
        ", periodictasks_monitor_check_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_check_taskPeriodMillis) +
        ", periodictasks_monitor_publish_aspicTemp_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_aspicTemp_taskPeriodMillis) +
        ", periodictasks_monitor_publish_boardPower_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_boardPower_taskPeriodMillis) +
        ", periodictasks_monitor_publish_crVolt_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_crVolt_taskPeriodMillis) +
        ", periodictasks_monitor_publish_rebTemp_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_rebTemp_taskPeriodMillis) +
        ", periodictasks_monitor_publish_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_publish_taskPeriodMillis) +
        ", periodictasks_monitor_update_aspicTemp_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_aspicTemp_taskPeriodMillis) +
        ", periodictasks_monitor_update_boardPower_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_boardPower_taskPeriodMillis) +
        ", periodictasks_monitor_update_crVolt_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_crVolt_taskPeriodMillis) +
        ", periodictasks_monitor_update_rebTemp_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_rebTemp_taskPeriodMillis) +
        ", periodictasks_monitor_update_taskPeriodMillis=" + Arrays.toString(periodictasks_monitor_update_taskPeriodMillis) +
        "}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private String location;

    private long[] periodictasks_monitor_check_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_boardPower_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_crVolt_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_rebTemp_taskPeriodMillis;

    private long[] periodictasks_monitor_publish_taskPeriodMillis;

    private long[] periodictasks_monitor_update_aspicTemp_taskPeriodMillis;

    private long[] periodictasks_monitor_update_boardPower_taskPeriodMillis;

    private long[] periodictasks_monitor_update_crVolt_taskPeriodMillis;

    private long[] periodictasks_monitor_update_rebTemp_taskPeriodMillis;

    private long[] periodictasks_monitor_update_taskPeriodMillis;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder location(String location) {
      this.location = location;
      return this;
    }

    public Builder periodictasks_monitor_check_taskPeriodMillis(
        long[] periodictasks_monitor_check_taskPeriodMillis) {
      this.periodictasks_monitor_check_taskPeriodMillis = periodictasks_monitor_check_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_aspicTemp_taskPeriodMillis(
        long[] periodictasks_monitor_publish_aspicTemp_taskPeriodMillis) {
      this.periodictasks_monitor_publish_aspicTemp_taskPeriodMillis = periodictasks_monitor_publish_aspicTemp_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_boardPower_taskPeriodMillis(
        long[] periodictasks_monitor_publish_boardPower_taskPeriodMillis) {
      this.periodictasks_monitor_publish_boardPower_taskPeriodMillis = periodictasks_monitor_publish_boardPower_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_crVolt_taskPeriodMillis(
        long[] periodictasks_monitor_publish_crVolt_taskPeriodMillis) {
      this.periodictasks_monitor_publish_crVolt_taskPeriodMillis = periodictasks_monitor_publish_crVolt_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_rebTemp_taskPeriodMillis(
        long[] periodictasks_monitor_publish_rebTemp_taskPeriodMillis) {
      this.periodictasks_monitor_publish_rebTemp_taskPeriodMillis = periodictasks_monitor_publish_rebTemp_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_publish_taskPeriodMillis(
        long[] periodictasks_monitor_publish_taskPeriodMillis) {
      this.periodictasks_monitor_publish_taskPeriodMillis = periodictasks_monitor_publish_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_aspicTemp_taskPeriodMillis(
        long[] periodictasks_monitor_update_aspicTemp_taskPeriodMillis) {
      this.periodictasks_monitor_update_aspicTemp_taskPeriodMillis = periodictasks_monitor_update_aspicTemp_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_boardPower_taskPeriodMillis(
        long[] periodictasks_monitor_update_boardPower_taskPeriodMillis) {
      this.periodictasks_monitor_update_boardPower_taskPeriodMillis = periodictasks_monitor_update_boardPower_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_crVolt_taskPeriodMillis(
        long[] periodictasks_monitor_update_crVolt_taskPeriodMillis) {
      this.periodictasks_monitor_update_crVolt_taskPeriodMillis = periodictasks_monitor_update_crVolt_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_rebTemp_taskPeriodMillis(
        long[] periodictasks_monitor_update_rebTemp_taskPeriodMillis) {
      this.periodictasks_monitor_update_rebTemp_taskPeriodMillis = periodictasks_monitor_update_rebTemp_taskPeriodMillis;
      return this;
    }

    public Builder periodictasks_monitor_update_taskPeriodMillis(
        long[] periodictasks_monitor_update_taskPeriodMillis) {
      this.periodictasks_monitor_update_taskPeriodMillis = periodictasks_monitor_update_taskPeriodMillis;
      return this;
    }

    public Focal_plane_Reb_timersConfigurationEvent build() {
      return new Focal_plane_Reb_timersConfigurationEvent(version, location, periodictasks_monitor_check_taskPeriodMillis, periodictasks_monitor_publish_aspicTemp_taskPeriodMillis, periodictasks_monitor_publish_boardPower_taskPeriodMillis, periodictasks_monitor_publish_crVolt_taskPeriodMillis, periodictasks_monitor_publish_rebTemp_taskPeriodMillis, periodictasks_monitor_publish_taskPeriodMillis, periodictasks_monitor_update_aspicTemp_taskPeriodMillis, periodictasks_monitor_update_boardPower_taskPeriodMillis, periodictasks_monitor_update_crVolt_taskPeriodMillis, periodictasks_monitor_update_rebTemp_taskPeriodMillis, periodictasks_monitor_update_taskPeriodMillis);
    }
  }
}
